<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package rws_myself
 */

get_header(); ?>


<div id="primary" class="content-area">
	<main id="main" class="site-main" role="main">
		<?php if (get_theme_mod('hide_service') == '') { ?>
		<section id="home-page-service">
			<div class="container-fluid">
				<div classs="row">
					<div class="home-service-wrapper clearfix">
						<h3><span class="fa fa-globe"></span>Services</h3>
						<?php
                            // Get pages set in the customizer (if any)
						$pages = array();
						for ($count = 1; $count <= 3; $count++) {
							$mod = get_theme_mod('service-page-' . $count);
							if ('page-none-selected' != $mod) {
								$pages[] = $mod;
							}
						}
						$args = array(
							'posts_per_page' => 3,
							'post_type' => 'page',
							'post__in' => $pages,
							'orderby' => 'post__in'
							);
						$query = new WP_Query($args);
						if ($query->have_posts()) :
							$count = 1;
						while ($query->have_posts()) : $query->the_post();
						?>
						<article class="service-col col-sm-5 col-3-part"
						id="post-<?php the_ID(); ?>" <?php post_class('featured-' . $count); ?>>
						<figure class="service-image">
							<a href="<?php echo get_permalink();?>">
								<?php the_post_thumbnail('service-front'); ?>
							</a>
						</figure>
						<h3> <span class="service-title"> <?php the_title(sprintf('<a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a>'); ?></span>
						</h3>
						<?php
						$page_id = get_the_ID();
						$page_data = get_page($page_id);
						$content = $page_data->post_content;
						$trimmed_content = wp_trim_words($content, 20);
						?>
						<p> <?php echo $trimmed_content; ?></p>
						<a href="<?php the_permalink(); ?>" class="btn">view more</a>
					</article><!--.service-col-->
					<?php
					$count++;
					endwhile;
					else :
						if (current_user_can('customize')) { ?>
					<div class="message">
						<p><?php _e('There are no pages available to display.', 'avalanche'); ?></p>

						<p><?php printf(
							__('These pages can be set in the <a href="%s">customizer</a>.', 'avalanche'),
							admin_url('customize.php?autofocus[control]=service')
							); ?>
						</p>
					</div>
					<?php }
					endif;
					?>
					<!--.service-col-->
				</div>
				<!--.home-service-wrapper-->
			</div>
		</div>
	</section>
	<?php } ?>
	
	<!--#home-page-service-->
	<?php if( get_theme_mod( 'hide_skill' )== '' ) { ?>
	<section id="skills-section">
		<div class="container">
			<div class="row">
				<h3> <span class="fa fa-trophy"></span> Skills
				</h3>

				<?php for($count = 1; $count <= 10; $count++){?>
				<?php if(get_theme_mod('skill-name'.$count)){?>
				<div class="skillbar clearfix " data-percent="<?php echo get_theme_mod('skill-percent'.$count)?>%">

					<?php if(get_theme_mod('rws_link_color'.$count)){?>
					<div class="skillbar-title" style="background: <?php echo get_theme_mod('rws_link_color'.$count)?>;">

						<?php if(get_theme_mod('skill-name'.$count)){?>
					<span><?php echo get_theme_mod('skill-name'.$count)?></span></div><?php }}?>
						

						<?php if(get_theme_mod('rws_link_color'.$count)){?>
						<div class="skillbar-bar" style="background: <?php echo get_theme_mod('rws_link_color'.$count)?>;"></div><?php }?>
						<?php if(get_theme_mod('skill-percent'.$count)){?>
						<div class="skill-bar-percent"><?php echo get_theme_mod('skill-percent'.$count)?>%</div><?php }?>
					</div> <!-- End Skill Bar -->
				<?php }}?>
					
</div>
</div>  
</section>
<?php }?>

<?php if( get_theme_mod( 'hide_about' )== '' ) { ?>
<section id="home-page-about">
	<div class="container">
		<div class="row clearfix">
			<article class= "about-me col-md-10 col-sm-10">
				<?php if(get_theme_mod('rws_about_title')){?>
				<h3><span class="fa fa-info"></span><span class="title"><?php echo get_theme_mod('rws_about_title');?></span></h3><?php }?> 
				<?php if(get_theme_mod('rws_about_description')){?>
				<p><?php echo get_theme_mod('rws_about_description');?></p><?php }?>
			</article><!--.about-me-->
		</article>
		<figure class="about-figure col-md-6 col-sm-6 alignright">
			<?php if (get_theme_mod('rws_about_image')){ ?>
			<?php $imagesrc = wp_get_attachment_image_src(absint(get_theme_mod('rws_about_image')),'full');?>
			<img src="<?php echo $imagesrc[0];?>"/><?php }?>
		</figure></div>
	</section><!--#home-page-about-->
	<?php }?>
	
	<section id="home-page-blog">
		<div class="container">
			<div class="row">
				<h3><span class="fa fa-file"></span>Latest Blogs</h3>
				<?php 
				$args = array(
					'post_type'	=> 'post',
					'posts_per_page'=>3,
					'orderby'	=> 'ASC',
					'ignore_sticky_posts' => 1
					
					);
				$query = new WP_Query($args);
				if($query->have_posts()): while($query->have_posts()): $query->the_post();?>
				<div class="home-posts col-md-5 col-sm-5 col-3-part">
					<?php if(has_post_thumbnail()) {?>
					<figure>
						<a href="<?php echo get_permalink();?>"><?php the_post_thumbnail('blog_front');?></a>
					</figure>
					<?php } else {?>
					<figure>
						<a href="<?php echo get_permalink();?>"><img src="<?php echo get_template_directory_uri();?>/lib/images/default-post-image.png"></a>
					</figure>
					<?php }?>
					<div class="post-content">
						<h2><a href="<?php echo get_permalink();?>"><?php the_title();?></a></h2>
					</div>
				</div>
			<?php endwhile; ?>
		<?php else : ?>
			<p><?php _e( 'Sorry, no posts matched your criteria.' ); ?></p>
		<?php endif;?>
	</div>
</div>
</section>
</main>
</div>

<?php get_footer(); ?>

