<?php
/**
 * rws_myself functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package rws_myself
 */

if ( ! function_exists( 'rws_myself_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function rws_myself_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on rws_myself, use a find and replace
	 * to change 'avalanche' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'avalanche', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'avalanche' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'rws_myself_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'rws_myself_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rws_myself_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'rws_myself_content_width', 640 );
}
add_action( 'after_setup_theme', 'rws_myself_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rws_myself_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'avalanche' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'rws_myself_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rws_myself_scripts() {

	// Add Bootstrap default CSS
	wp_enqueue_style( 'rws_myself-bootstrap', get_template_directory_uri() . '/lib/css/bootstrap.min.css' );

	// Add Font Awesome stylesheet
	wp_enqueue_style( 'rws_myself-icons', get_template_directory_uri().'/lib/css/font-awesome.min.css' );

	// Add Mean Menu stylesheet
	wp_enqueue_style( 'rws_myself-mobmenu', get_template_directory_uri().'/lib/css/meanmenu.css' );

	// Add Flexslider stylesheet
	wp_enqueue_style( 'rws_myself-slider', get_template_directory_uri().'/lib/css/flexslider.css' );
	
	// Add Animation stylesheet
	wp_enqueue_style( 'rws_myself-animation', get_template_directory_uri().'/lib/css/animated.css' );

	//	Add Google Fonts
	wp_register_style( 'rws_myself-fonts1', '//fonts.googleapis.com/css?family=Lobster+Two:700,400italic');
	wp_enqueue_style( 'rws_myself-fonts1' );

	//	Add Google Fonts
	wp_register_style( 'rws_myself-fonts2', '//fonts.googleapis.com/css?family=Raleway:600,700');
	wp_enqueue_style( 'rws_myself-fonts2' );

	//	Add Google Fonts
	wp_register_style( 'rws_myself-fonts3', '//fonts.googleapis.com/css?family=Roboto+Condensed:400,700');
	wp_enqueue_style( 'rws_myself-fonts3' );

	// Add main theme stylesheet
	wp_enqueue_style( 'rws_myself-style', get_stylesheet_uri() );

	// Add JS library
	wp_enqueue_script('rws_myself-jquery', get_template_directory_uri().'/js/vendor/jquery-1.11.0.min.js', array('jquery') );

	// Add Modernizr for better HTML5 and CSS3 support
	wp_enqueue_script('rws_myself-modernizr', get_template_directory_uri().'/js/vendor/modernizr-2.7.1.min.js', array('jquery') );

	// Add Bootstrap default JS
	wp_enqueue_script('rws_myself-bootstrapjs', get_template_directory_uri().'/js/vendor/bootstrap.min.js', array('jquery') );


	wp_enqueue_script( 'rws_myself-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	// Add plugin JS
	wp_enqueue_script('rws_myself-plugin', get_template_directory_uri().'/js/plugins.js', array('jquery') );

	// Add custom JS
	wp_enqueue_script('rws_myself-scripts', get_template_directory_uri().'/js/scripts.js', array('jquery') );

	wp_enqueue_script( 'rws_myself-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rws_myself_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/inc/rws-hook.php';

/*function rws_myself_header_image(){?>

<style type="text/css">
       #bottom-header #banner {
    background: #000 url(<?php header_image(); ?>) no-repeat center center/cover;;
}
    </style><?php
}*/

add_image_size('service-front', 300,300, true);

add_image_size('blog_front', 300,250, true);

add_editor_style('editor-style.css');