<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package rws_myself
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <!--[if IE 8]>
    <link href="<?php echo get_template_directory_uri();?>/lib/css/ie8.css" rel="stylesheet" />
    <![endif]-->

    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div class="outer-wrapper">
    <div id="page" class="site">
        <a class="skip-link screen-reader-text"
           href="#content"><?php esc_html_e('Skip to content', 'avalanche'); ?></a>

        <header id="masthead" class="site-header">
            <header id="top-header">
                <div class="container">
                    <div class="row">
                        <?php
                        if (get_theme_mod('rws_myself_header_logo_image', '') != ''){ ?>
                            <div id="header-logo-image" class="col-md-4 alignleft">
                                <a href="<?php echo esc_url(home_url('/')); ?>"
                                   title="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>" rel="home">
                                    <img src="<?php echo get_theme_mod('rws_myself_header_logo_image'); ?>"
                                         alt="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>"></a>
                        <?php } else{ ?>
                        <!-- #header-logo-image -->
                        <div class="site-branding col-md-6 alignleft">
                            <?php
                            if (is_front_page() && is_home()) : ?>
                                <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                                          rel="home"><?php bloginfo('name'); ?></a></h1>
                            <?php else : ?>
                                <p class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                                         rel="home"><?php bloginfo('name'); ?></a></p>
                                <?php
                            endif;

                            $description = get_bloginfo('description', 'display');
                            if ($description || is_customize_preview()) : ?>
                                <p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
                                <?php
                            endif;
                            } ?>
                        </div>
                        <!-- .site-branding -->

                        <div class="top-header-right col-md-10 alignright">

                            <ul class="social-links col-md-8 alignleft">
                                <?php if (get_theme_mod('rws_myself_facebook_url')): ?>
                                    <li><a href="<?php echo get_theme_mod('rws_myself_facebook_url'); ?>" target="_blank"
                                           class="fa fa-facebook"></a></li>
                                <?php endif; ?>
                                <?php if (get_theme_mod('rws_myself_twitter_url')): ?>
                                    <li><a href="<?php echo get_theme_mod('rws_myself_twitter_url'); ?>" target="_blank"
                                           class="fa fa-twitter"></a></li>
                                <?php endif; ?>
                                <?php if (get_theme_mod('rws_myself_google+_url')): ?>
                                    <li><a href="<?php echo get_theme_mod('rws_myself_google+_url'); ?>" target="_blank"
                                           class="fa fa-google-plus"></a></li>
                                <?php endif; ?>
                                <?php if (get_theme_mod('rws_myself_instagram_url')): ?>
                                    <li><a href="<?php echo get_theme_mod('rws_myself_instagram_url'); ?>" target="_blank"
                                           class="fa fa-instagram"></a></li>
                                <?php endif; ?>
                                <?php if (get_theme_mod('rws_myself_linkedin_url')): ?>
                                    <li><a href="<?php echo get_theme_mod('rws_myself_linkedin_url'); ?>" target="_blank"
                                           class="fa fa-linkedin"></a></li>
                                <?php endif; ?>
                                <?php if (get_theme_mod('rws_myself_youtube_url')): ?>
                                    <li><a href="<?php echo get_theme_mod('rws_myself_youtube_url'); ?>" target="_blank"
                                           class="fa fa-youtube"></a></li>
                                <?php endif; ?>
                            </ul>
                            <!--.social-links-->


                                <div class="form-wrapper col-md-8">
                                    <?php get_search_form(); ?>
                                </div>
                                <!--.form-wrapper-->
                            </div>
                            <!--.search-form-wrapper-->

                                <nav id="site-navigation" class="main-navigation col-md-16" role="navigation">
                                    <button class="menu-toggle" aria-controls="primary-menu"
                                            aria-expanded="false"><?php esc_html_e('Primary Menu', 'avalanche'); ?></button>
                                    <?php wp_nav_menu(array('theme_location' => 'primary', 'menu_id' => 'primary-menu', 'menu_class' => 'clearfix menu')); ?>
                                </nav>
                                <!-- #site-navigation -->
                        </div>
                        <!--.top-header-right-->

                    </div>
                    <!--.row-->
                </div>
                <!--.container-->
            </header>
            <!--#top-header-->
            <header id="bottom-header">
                <?php if (get_header_image()) : ?>
                    <a href="<?php echo esc_url(home_url('/')); ?>" rel="home">
                        <img src="<?php header_image(); ?>" width="<?php echo esc_attr(get_custom_header()->width); ?>"
                             height="<?php echo esc_attr(get_custom_header()->height); ?>" alt="">
                    </a>
                <?php endif; // End header image check. ?>


                <?php if (false === get_theme_mod('rws_myself_header_slider')){ ?>


                <div id="banner">
                    <div class="container-fluid">
                        <div class="row">
                         <?php if(is_front_page()){?>
                        <?php if( get_theme_mod( 'hide_slider' ) == '') { ?>
                            <div id="banner-slider" class="flexslider">
                                <ul class="slides">


                                    <?php for ($i = 1; $i <= 6; $i++) {
                                        ?>
                                        <?php if(get_theme_mod('rws_myself_header_slider_image'.$i)) { ?>
                                        <li>
                                            <div class="slider-content-wrapper" style="background: url('<?php echo get_theme_mod('rws_myself_header_slider_image'.$i); ?>') no-repeat center center; background-size: cover;">

                                                <div class="slider-content">
                                                    <?php if (get_theme_mod('rws_myself_header_title'.$i)) { ?>
                                                        <h3>
                                                            <a href="#"><?php echo get_theme_mod('rws_myself_header_title'.$i); ?></a>
                                                        </h3>
                                                    <?php } ?>
                                                    <?php if (get_theme_mod('rws_myself_header_description'.$i)) { ?>
                                                        <p><?php echo wp_trim_words(get_theme_mod('rws_myself_header_description'.$i), 20); ?>
                                                        </p>
                                                    <?php } ?>
                                                    <?php if(get_theme_mod('rws_myself_header_readmore'.$i)){ ?>
                                                    <a href="<?php echo get_theme_mod('rws_myself_header_readmore'.$i);?>" class="btn">Read More</a>
                                                    <?php }?>
                                                </div>
                                                <!--.slider-content-->
                                            </div>
                                            <!--.slider-content-wrapper-->

                                        </li>
                                        <?php }?>
                                    <?php } ?>
                                </ul>

                            </div>
                            <?php }?>
                        </div>
                    </div>
                    <?php }} ?>

                    <!--		#banner-->
            </header>
            <!--		#bottom-header-->
        </header>
        <!-- #masthead -->

        <div id="content" class="site-content">
            <div class="container-fluid">
                <div class="row">
